@@ -1,4 +1,4 @@
-// Java mousetrap application. Copyright  1999 Santa Fe Institute.
+// Java mousetrap application. Copyright  1999-2000 Swarm Development Group.
 // This application is distributed without any warranty; without even
 // the implied warranty of merchantability or fitness for a particular
 // purpose.  See file COPYING for details and terms of copying.
@@ -9,8 +9,7 @@ import swarm.defobj.ZoneImpl;
  * This class provides the `main' function of the Mousetrap application */
 public class StartMousetrap {
   public static void main (String[] args) {
-    Globals.env.initSwarm ("jmousetrap", "2.0.1", "bug-swarm@santafe.edu",
-                           args);
+    Globals.env.initSwarm ("jmousetrap", "2.1", "bug-swarm@swarm.org", args);
     
     if (Globals.env.guiFlag) {
       MousetrapObserverSwarm topLevelSwarm =
